@@ -587,6 +587,41 @@ Interfaces::Internal::Internal()
 
 #else /* _WIN32 ->*/
 
+bool wchartoutf8(const wchar_t *in, std::string& out, size_t wlen)
+{
+    out.clear();
+    if (nullptr == in) {
+        return true;
+    }
+    if (wlen == 0) {
+        wlen = wcslen(in);
+    }
+    int flags = WC_ERR_INVALID_CHARS;
+    int bytes = ::WideCharToMultiByte(CP_UTF8, flags, in, wlen, nullptr, 0, nullptr, nullptr);
+    if (bytes <= 0) {
+        LOGERR("wchartoutf8: conversion error1\n");
+        fwprintf(stderr, L"wchartoutf8: conversion error1 for [%s]\n", in);
+        return false;
+    }
+    char *cp = (char *)malloc(bytes+1);
+    if (nullptr == cp) {
+        LOGERR("wchartoutf8: malloc failed\n");
+        return false;
+    }
+    bytes = ::WideCharToMultiByte(CP_UTF8, flags, in, wlen, cp, bytes, nullptr, nullptr);
+    if (bytes <= 0) {
+        LOGERR("wchartoutf8: CONVERSION ERROR2\n");
+        free(cp);
+        return false;
+    }
+    cp[bytes] = 0;
+    out = cp;
+    free(cp);
+    //fwprintf(stderr, L"wchartoutf8: in: [%s]\n", in);
+    //fprintf(stderr, "wchartoutf8: out:  [%s]\n", out.c_str());
+    return true;
+}
+
 static uint32_t netprefixlentomask(uint8_t pfxlen)
 {
     uint32_t out{0};
@@ -615,8 +650,7 @@ Interfaces::Internal::Internal()
     
     /* Get Adapters addresses required size. */
     ret = GetAdaptersAddresses(
-        AF_UNSPEC,  GAA_FLAG_SKIP_ANYCAST | GAA_FLAG_SKIP_DNS_SERVER,
-        NULL, adapts, &adapts_sz);
+        AF_UNSPEC,  GAA_FLAG_SKIP_ANYCAST | GAA_FLAG_SKIP_DNS_SERVER, NULL, adapts, &adapts_sz);
     if (ret != ERROR_BUFFER_OVERFLOW) {
         LOGERR("NetIF::Interfaces: GetAdaptersAddresses: ret1 " << ret <<"\n");
         return;
@@ -629,8 +663,7 @@ Interfaces::Internal::Internal()
     }
     /* Do the call that will actually return the info. */
     ret = GetAdaptersAddresses(
-        AF_UNSPEC, GAA_FLAG_SKIP_ANYCAST | GAA_FLAG_SKIP_DNS_SERVER,
-        NULL, adapts, &adapts_sz);
+        AF_UNSPEC, GAA_FLAG_SKIP_ANYCAST | GAA_FLAG_SKIP_DNS_SERVER, NULL, adapts, &adapts_sz);
     if (ret != ERROR_SUCCESS) {
         LOGERR("NetIF::Interfaces: GetAdaptersAddresses: ret2 " << ret <<"\n");
         goto out;
@@ -641,18 +674,15 @@ Interfaces::Internal::Internal()
         auto ifit = find_if(vifs.begin(), vifs.end(),
                             [adapts_item] (const Interface& ifr) {
                                 return adapts_item->AdapterName == ifr.m->name;});
-        /* We're converting chars using the current code page. It would be nicer
-           to convert to UTF-8 */
-        char tmpnm[256];
-               wcstombs(tmpnm, adapts_item->FriendlyName, sizeof(tmpnm));
         if (ifit == vifs.end()) {
             LOGDEB("NetIF::Interfaces: I/F friendlyname " << tmpnm <<
                    " AdapterName " << adapts_item->AdapterName << "\n");
             vifs.emplace_back(adapts_item->AdapterName);
             ifit = --vifs.end();
         }
-
-        ifit->m->friendlyname = tmpnm;
+        if (!wchartoutf8(adapts_item->FriendlyName, ifit->m->friendlyname, 0)) {
+            ifit->m->friendlyname = adapts_item->AdapterName;
+        }
         if (!(adapts_item->Flags & IP_ADAPTER_NO_MULTICAST)) {
             LOGDEB("NetIF::Interfaces: " << tmpnm << " has MULTICAST\n");
             ifit->m->setflag(Interface::Flags::MULTICAST);
@@ -794,11 +824,15 @@ static const Interface* interfaceForAddress4(
             if (addresses.first[i].family() == IPAddr::Family::IPV4) {
                 addresses.first[i].copyToStorage(&sbuf);
                 addresses.second[i].copyToStorage(&mbuf);
-                uint32_t addr = reinterpret_cast<struct sockaddr_in*>(
-                    &sbuf)->sin_addr.s_addr;
-                uint32_t mask = reinterpret_cast<struct sockaddr_in*>(
-                    &mbuf)->sin_addr.s_addr;
-                if ((peeraddr & mask) == (addr & mask)) {
+                uint32_t addr = reinterpret_cast<struct sockaddr_in*>(&sbuf)->sin_addr.s_addr;
+                uint32_t mask = reinterpret_cast<struct sockaddr_in*>(&mbuf)->sin_addr.s_addr;
+                if (
+                    // Special case for having a single interface with a netmask of ffffffff, which
+                    // is apparently common from FreeBSD jails. Just return it, there is no way we
+                    // can check anything.
+                    ((vifs.size() == 1) && (mask == 0xffffffff)) ||
+                    // Normal subnet check
+                    ((peeraddr & mask) == (addr & mask)) ) {
                     hostaddr = addresses.first[i];
                     return &netif;
                 }
